@@ -33,6 +33,9 @@ class EngineQueryHelper(QueryHelper):
             returns:
                 service (Service): The Service model
         """
+        if not for_update:
+            return super().get_service(slug=slug)
+
         return self.get_query(Service, for_update).filter(
             and_(
                 Service.slug == slug,
