@@ -4,7 +4,6 @@
 import json
 from sdc_helpers.models.client import Client
 import boto3
-from sdc_engine_helpers import queue_utils
 from sdc_engine_helpers.personalize.manager import Manager
 
 
@@ -66,14 +65,6 @@ class RecommendationsManager(Manager):
         else:
             results = json.loads(results)
 
-        queue_utils.queue_s3_recommendations_store(
-            client=client,
-            engine='personalize',
-            results=results,
-            item_id=item_id,
-            context=self.parameters.get('context', {})
-        )
-
         return results
 
     def get_results(self, *, client: Client, campaign_arn: str, default_results: list) -> list:
