@@ -123,6 +123,7 @@ class DatasetStateManager:
 
     def download_s3_blob(self, s3_url: str):
         """download blob from s3"""
+        print("Starting.. Download blob")
         # parse s3 url -> bucket, file_path
         bucket, file_path = parse_s3_url(s3_url)
         # load data from s3 as byte steam
@@ -135,6 +136,10 @@ class DatasetStateManager:
             )
             data_stream.seek(0)
 
+            return json.loads(
+                data_stream.read().decode("UTF-8")
+            )
+
         except botocore_clienterror as exception:
             if exception.response['Error']['Code'] == "404":
                 # The object does not exist.
@@ -142,10 +147,8 @@ class DatasetStateManager:
                     "Unable to find s3 object. Skipping the task, "
                     "the following exception was found = {}".format(exception)
                 ))
-            else:
-                raise
-
-        return data_stream
+                return None
+            raise
 
     def upload_s3_blob(self, blob: io.BytesIO, s3_url: str):
         """download blob from s3"""
@@ -194,7 +197,7 @@ class DatasetStateManager:
             self.redis_helper.redis_delete(keys=[cache_key])
 
     def cache_lookup(self, json_data: dict, cache_key: str):
-        """cache lookup in elasticcache
+        """cache lookup in elastic cache
 
         Args:
             cache_key (str): key to use when caching
@@ -348,24 +351,19 @@ class DatasetStateManager:
 
                 print("Download dataset from prod/ in s3")
 
-                data_stream = self.download_s3_blob(s3_url=prod_url)
-                # load json data from bytes stream
-                json_data = json.loads(
-                    data_stream.read().decode("UTF-8")
-                )
-                print("Pushing to previous/ to s3")
-                self.execute_s3_versioning(
-                    json_data=json_data,
-                    dst_url=previous_url
-                )
+                json_data = self.download_s3_blob(s3_url=prod_url)
+                if isinstance(json_data, dict):
+                    print("Pushing to previous/ to s3")
+                    self.execute_s3_versioning(
+                        json_data=json_data,
+                        dst_url=previous_url
+                    )
 
-                print("Download dataset from train/ from s3")
-                # get data
-                data_stream = self.download_s3_blob(s3_url=identifier)
-                json_data = json.loads(
-                    data_stream.read().decode("UTF-8")
-                )
+            print("Download dataset from train/ from s3")
+            # get data
+            json_data = self.download_s3_blob(s3_url=identifier)
 
+            if isinstance(json_data, dict):
                 tmp_cache_clone = "{}-tmp-clone".format(cache_key)
                 print("Creating a dataset clone")
                 self.cache_lookup(
