@@ -5,6 +5,8 @@
 from datetime import datetime
 import sdc_helpers.utils as utils
 import boto3
+from sdc_engine_helpers.sagemaker.utils import \
+    create_resource_name, build_resource_tags
 from sdc_engine_helpers.sagemaker.utils import name_from_base
 from sdc_engine_helpers.date_utils import DateUtils
 
@@ -22,6 +24,13 @@ class SolutionStateManager:
 
     """
     date_utils = DateUtils()
+    # default tag to dev environment
+    resource_tags = [
+        {
+            'Key': 'environment',
+            'Value': 'dev'
+        },
+    ]
     # slack_helper = SlackHelper()
     # set path to entities in vendor objects
     solution_status_path = 'TrainingJobStatus'
@@ -57,7 +66,13 @@ class SolutionStateManager:
         # get vendor api
         self.sagemaker = boto3.client('sagemaker')
 
-    def sagemaker_create_solution(self, training_job_name: str, new_solution_name: str) -> str:
+    def sagemaker_create_solution(
+            self,
+            training_job_name: str,
+            client_code: str,
+            service_slug: str,
+            engine_slug: str
+    ) -> str:
         """Performs a create solution API execution to create new solution version job
 
             Args:
@@ -67,33 +82,64 @@ class SolutionStateManager:
             Returns:
                 (str) : new training job name
         """
-
+        new_solution_base_name = create_resource_name(
+            context=service_slug,
+            function=client_code, # to maintain order of resource name
+            additional_details=[
+                engine_slug, 'training'
+            ]
+        )
         # get current solution
         prev_training_job = self.sagemaker.describe_training_job(
             TrainingJobName=training_job_name
         )
 
-        new_training_job = {}
+        new_training_job_config = {}
         for key_, values_ in prev_training_job.items():
             if key_ in self.required_new_job_fields:
-                new_training_job.update({
+                new_training_job_config.update({
                     key_ : values_
                 })
 
         # update fields
         # generate a unique name with timestamp
         new_training_job_name = name_from_base(
-            new_solution_name,
+            new_solution_base_name,
             max_length=63,
             short=False
         )
-        new_training_job.update({
-            'TrainingJobName': new_training_job_name
+
+        # add new resource tags
+        resource_tags = build_resource_tags(
+            current_tags=self.resource_tags,
+            new_tags=[
+                {
+                    'Key': 'environment',
+                    'Value': 'prod'
+                },
+                {
+                    'Key': 'client',
+                    'Value': client_code
+                },
+                {
+                    'Key': 'engine',
+                    'Value': engine_slug
+                },
+                {
+                    'Key': 'service',
+                    'Value': service_slug
+                }
+            ]
+        )
+
+        new_training_job_config.update({
+            'TrainingJobName': new_training_job_name,
+            'Tags': resource_tags
         })
 
-        self.sagemaker.create_training_job(**new_training_job)
+        self.sagemaker.create_training_job(**new_training_job_config)
 
-        return new_training_job['TrainingJobName']
+        return new_training_job_config['TrainingJobName']
 
     def get_vendor_version_status(self, *, vendor_solution: dict) -> str:
         """
@@ -204,7 +250,13 @@ class SolutionStateManager:
 
         return True
 
-    def update_state(self, solution: dict, solution_base_name: str):
+    def update_state(
+            self,
+            solution: dict,
+            client_code: str,
+            service_slug: str,
+            engine_slug: str
+    ):
         """
             Run the update workflow for solution
 
@@ -224,7 +276,9 @@ class SolutionStateManager:
 
         new_solution_arn = self.sagemaker_create_solution(
             training_job_name=solution['arn'],
-            new_solution_name=solution_base_name
+            client_code=client_code,
+            service_slug=service_slug,
+            engine_slug=engine_slug
         )
         # update the arn with the new arn
         new_solution.update({
