@@ -191,8 +191,7 @@ class RecommendationsManager:
     def encode_item_code(
             self,
             *,
-            item_ids: list,
-            from_cache: bool = True
+            item_ids: list
     ):
         """
             Lookup a list of item codes
@@ -217,14 +216,12 @@ class RecommendationsManager:
         key_exists = self.redis_helper.redis_hexists(
             hashkey=cache_key
         )
-        print("Cached Key = {}".format(cache_key))
-        print("keys found = {}".format(key_exists))
+
         if key_exists == 0:
-            print("Falling back to clone")
             tmp_cache_clone = "{}-tmp-clone".format(cache_key)
             # check that key exists
             key_exists = self.redis_helper.redis_hexists(
-                hashkey=cache_key
+                hashkey=tmp_cache_clone
             )
             if key_exists == 0:
                 raise Exception((
@@ -234,12 +231,11 @@ class RecommendationsManager:
             # use clone as lookup
             cache_key = tmp_cache_clone
 
-        if from_cache:
-            # encode item_id -> item_code
-            item_codes = self.redis_helper.redis_hmget(
-                hashkey=cache_key,
-                keys=item_ids
-            )
+        # encode item_id -> item_code
+        item_codes = self.redis_helper.redis_hmget(
+            hashkey=cache_key,
+            keys=item_ids
+        )
 
         results = []
         for item_code in item_codes:
@@ -256,8 +252,7 @@ class RecommendationsManager:
     def decode_item_code(
             self,
             *,
-            item_codes: list,
-            from_cache: bool = True
+            item_codes: list
     ):
         """"
             Lookup a list of item ids
@@ -279,14 +274,13 @@ class RecommendationsManager:
         key_exists = self.redis_helper.redis_hexists(
             hashkey=cache_key
         )
-        print("Cached Key = {}".format(cache_key))
-        print("keys found = {}".format(key_exists))
+
         if key_exists == 0:
-            print("Falling back to clone")
             tmp_cache_clone = "{}-tmp-clone".format(cache_key)
+
             # check that key exists
             key_exists = self.redis_helper.redis_hexists(
-                hashkey=cache_key
+                hashkey=tmp_cache_clone
             )
 
             if key_exists == 0:
@@ -297,12 +291,12 @@ class RecommendationsManager:
             # use clone as lookup
             cache_key = tmp_cache_clone
 
-        if from_cache:
-            # decode item_codes -> item_ids
-            item_ids = self.redis_helper.redis_hmget(
-                hashkey=cache_key,
-                keys=item_codes
-            )
+        # if from_cache:
+        # decode item_codes -> item_ids
+        item_ids = self.redis_helper.redis_hmget(
+            hashkey=cache_key,
+            keys=item_codes
+        )
 
         results = []
         for item_id in item_ids:
